/*
	TuxPuck - boardentity.h
	Copyright (C) 2001 Jacob Kroon

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

	Jacob Kroon - d00jkr@efd.lth.se
*/

#ifndef _BOARDENTITY_H
#define _BOARDENTITY_H

class BoardEntity;
class Pad;
class Puck;

/* includes */
#ifndef _SDL_video_h
#include <SDL_video.h>
#endif
#ifndef _AUDIO_H
#include "audio.h"
#endif
#ifndef _GLOBAL_H
#include "global.h"
#endif
#ifndef _BOARD_H
#include "board.h"
#endif

/* defines */
#define PUCK_STATE_ALIVE	1
#define PUCK_STATE_DEAD		2

/* structs */
struct MoveArea
{
  float x1, x2, z1, z2;
};

/* class */
class BoardEntity
{
private:
  Board * _theBoard;
  Uint8 _transparent;
  SDL_Rect _oldRect;
protected:
    SDL_Surface * _sdlImage;
  MoveArea _moveArea;
  float _x, _z, _dx, _dz, _w, _h, _y_scale;
public:
    BoardEntity(Board *);
   ~BoardEntity();
  void blit(void);
  void erase(void);
  void move(Uint32);
  void getPosition(float *, float *);
  void setVelocity(float, float);
  void getVelocity(float *, float *);
  Uint8 moveTowards(float, float, Uint32);
  void toggleTransparent(void);
};

class Pad:public BoardEntity
{
private:
public:
  Pad(Board *, Uint8);
  ~Pad();
};

class Puck:public BoardEntity
{
private:
  Uint8 _state;
  Sound *_wavNock;
public:
    Puck(Board *);
   ~Puck();
  void move(Uint32);
  bool willGetHitBy(Pad *, Uint32);
  void getHitBy(Pad *, Uint32);
  void setState(Uint8);
  bool isDead(void);
};

#endif /* _BOARDENTITY_H */
