/*
	TuxPuck - menu.cpp
	Copyright (C) 2001 Jacob Kroon

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

	Jacob Kroon - d00jkr@efd.lth.se
*/

/* includes */
#include <malloc.h>
#include <string.h>
#include <SDL_events.h>
#include <SDL_timer.h>
#include "video.h"
#include "menu.h"

/* Menu implemention */
Menu::Menu(Font * _menuFont, Uint8 nbrOfLabels)
{
  _nbrOfLabels = nbrOfLabels;
  _label = (char **) calloc(nbrOfLabels, sizeof(char *));
  _w = 0;
  _h = nbrOfLabels * 40;
  _font = _menuFont;
}

Menu::~Menu()
{
  free(_label);
}

void Menu::_drawLabel(Uint8 label, SDL_Rect * rect)
{
  _font->setPen(320 - _font->calcWidth(_label[label]) / 2,
		240 - _nbrOfLabels * 12 / 2 + label * 40);
  _font->print(_label[label], rect);
}

void Menu::addLabel(Uint8 place, char *text)
{
  Uint8 i;

  _label[place] = text;
  if (_w == 0)
    _w = _font->calcWidth(text) + 20;
  for (i = 0; i < _nbrOfLabels; i++)
    if (_label[i])
      if (_w < _font->calcWidth(_label[i]) + 20)
	_w = _font->calcWidth(_label[i]) + 20;
}

Uint8 Menu::getCommand(void)
{
  SDL_Event event;
  SDL_Surface *background = NULL;
  Uint8 loop = 1, i = 0;
  Sint16 label = 0;
  SDL_Rect rect;

  rect.x = 320 - _w / 2;
  rect.y = 240 - _h / 2;
  rect.w = _w;
  rect.h = _h;
  Video::instance()->blendRect(128, &rect);
  _font->setColor(255, 255, 255);
  for (i = 0; i < _nbrOfLabels; i++)
    _drawLabel(i, NULL);
  background = Video::instance()->duplicate();
  _font->setColor(255, 0, 0);
  _drawLabel(0, &rect);
#ifndef _DEBUG
  SDL_WM_GrabInput(SDL_GRAB_OFF);
#endif
  while (loop)
    {
      while (SDL_PollEvent(&event))
	{
	  switch (event.type)
	    {
	    case SDL_KEYDOWN:
	      switch (event.key.keysym.sym)
		{
		case SDLK_RETURN:
		  loop = 0;
		  break;
		case SDLK_UP:
		  Video::instance()->erase(background, &rect);
		  label--;
		  if (label < 0)
		    label = _nbrOfLabels - 1;
		  _drawLabel(label, &rect);
		  break;
		case SDLK_DOWN:
		  Video::instance()->erase(background, &rect);
		  label++;
		  if (label >= _nbrOfLabels)
		    label = 0;
		  _drawLabel(label, &rect);
		  break;
		default:
		  break;
		}
	    }
	}
      SDL_Delay(5);
      Video::instance()->update();
    }
  SDL_FreeSurface(background);
  Video::instance()->restore();
#ifndef _DEBUG
  SDL_WM_GrabInput(SDL_GRAB_ON);
#endif
  SDL_PumpEvents();
  SDL_GetRelativeMouseState(NULL, NULL);
  return label;
}

/* GameMenu implemention */
GameMenu::GameMenu(Font * _menuFont):Menu(_menuFont, 2)
{
  this->addLabel(GAMEMENU_START_GAME, "Start Game");
  this->addLabel(GAMEMENU_QUIT, "Quit");
}

GameMenu::~GameMenu()
{
}

/* IngameMenu implemention */
IngameMenu::IngameMenu(Font * _menuFont):Menu(_menuFont, 2)
{
  this->addLabel(INGAMEMENU_EXIT_GAME, "Exit Game");
  this->addLabel(INGAMEMENU_CONTINUE, "Continue");
}

IngameMenu::~IngameMenu()
{
}

/* OpponentMenu implemention */
OpponentMenu::OpponentMenu(Font * _menuFont):Menu(_menuFont, 2)
{
  this->addLabel(OPPONENTMENU_TUX, "Tux");
  this->addLabel(OPPONENTMENU_CARTMAN, "Cartman");
}

OpponentMenu::~OpponentMenu()
{
}
